pub trait HasMinDistance<Q> {
// Required method
fn min_distance(&self, query: &Q) -> f64;
}Expand description
Trait for types that can compute the minimum distance to a given query.
Required Methods
Sourcefn min_distance(&self, query: &Q) -> f64
fn min_distance(&self, query: &Q) -> f64
Computes the minimum distance from the bounding volume to the given query.